/**
 * This file is part of GenomeView, a genome browser and annotation curator
 * 
 * Copyright (C) 2007-2017 Thomas Abeel and contributors
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Project: http://genomeview.org/
 */
package net.sf.jannot.alignment.maf;

import net.sf.jannot.Strand;
import net.sf.jannot.refseq.Sequence;
import net.sf.jannot.utils.SequenceTools;

/**
 * @author Thomas Abeel
 * 
 */
public class MemoryAlignmentSequence extends AbstractAlignmentSequence {
	private Sequence seq;

	/**
	 * @param e
	 * @param parseInt
	 * @param fromSymbol
	 * @param string
	 */
	public MemoryAlignmentSequence(String id, int start, int noNucleotides, int srcSize, Strand fromSymbol, Sequence seq) {
		super(id,fromSymbol == Strand.FORWARD?start: srcSize - start - noNucleotides,noNucleotides,fromSymbol);
		/* Overwrite start as well!! */
		if (fromSymbol == Strand.FORWARD) {
			this.seq = seq;
		} else {
			this.seq = SequenceTools.reverseComplement(seq);
		}
		this.noNucleotides = noNucleotides;
		this.strand = fromSymbol;

	}

	/* (non-Javadoc)
	 * @see net.sf.jannot.alignment.maf.AbstractAlignmentSequence#seq()
	 */
	@Override
	public Sequence seq() {
		return seq;
	}
}
