/**
 * This file is part of GenomeView, a genome browser and annotation curator
 * 
 * Copyright (C) 2007-2017 Thomas Abeel and contributors
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Project: http://genomeview.org/
 */
package net.sf.jannot.tabix.codec;

import java.util.Iterator;

import net.sf.jannot.tabix.TabixLine;
import be.abeel.util.LRUCache;

/**
 * @author Thomas Abeel
 * 
 */
public abstract class Codec<T> implements Iterable<T> {

	private Iterable<TabixLine> in;
	protected LRUCache<TabixLine, T> lru;
	
	public Codec(Iterable<TabixLine> in,int lruSize) {
		this.in = in;
		this.lru=new LRUCache<TabixLine, T>(lruSize);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Iterable#iterator()
	 */
	@Override
	public Iterator<T> iterator() {
		return new CodecIterator(in);
	}

	/**
	 * @param next
	 * @return
	 */
	public abstract T parse(TabixLine next);

	class CodecIterator implements Iterator<T> {

		private Iterator<TabixLine> it;

		/**
		 * @param in
		 */
		public CodecIterator(Iterable<TabixLine> in) {
			this.it = in.iterator();
		}

		/*
		 * (non-Javadoc)
		 * 
		 * @see java.util.Iterator#hasNext()
		 */
		@Override
		public boolean hasNext() {
			return it.hasNext();
		}

		/*
		 * (non-Javadoc)
		 * 
		 * @see java.util.Iterator#next()
		 */
		@Override
		public T next() {
			return parse(it.next());
		}

		/*
		 * (non-Javadoc)
		 * 
		 * @see java.util.Iterator#remove()
		 */
		@Override
		public void remove() {
			throw new UnsupportedOperationException();

		}

	}
}
